pub enum Color {
Black,
White,
}Expand description
Black/White colors
Variants
Implementations
Sourceimpl Color
impl Color
Sourcepub fn get_bit_value(self) -> u8
pub fn get_bit_value(self) -> u8
Get the color encoding of the color for one bit
Sourcepub fn get_byte_value(self) -> u8
pub fn get_byte_value(self) -> u8
Gets a full byte of black or white pixels